@@ -219,6 +219,10 @@ from ncbi.datasets.openapi.model.v1_transcript_transcript_type import V1Transcri
 from ncbi.datasets.openapi.model.v1_transcript_transcript_type import V1TranscriptTranscriptType as V1alpha1TranscriptTranscriptType
 from ncbi.datasets.openapi.model.v1_version_reply import V1VersionReply
 from ncbi.datasets.openapi.model.v1_version_reply import V1VersionReply as V1alpha1VersionReply
+from ncbi.datasets.openapi.model.v1_virus_availability import V1VirusAvailability
+from ncbi.datasets.openapi.model.v1_virus_availability import V1VirusAvailability as V1alpha1VirusAvailability
+from ncbi.datasets.openapi.model.v1_virus_availability_request import V1VirusAvailabilityRequest
+from ncbi.datasets.openapi.model.v1_virus_availability_request import V1VirusAvailabilityRequest as V1alpha1VirusAvailabilityRequest
 from ncbi.datasets.openapi.model.v1_virus_data_report_request import V1VirusDataReportRequest
 from ncbi.datasets.openapi.model.v1_virus_data_report_request import V1VirusDataReportRequest as V1alpha1VirusDataReportRequest
 from ncbi.datasets.openapi.model.v1_virus_data_report_request_content_type import V1VirusDataReportRequestContentType
